===
API
===

resonance/system.py
===================

.. automodule:: resonance.system
   :members:
   :undoc-members:

resonance/linear_systems.py
===========================

.. automodule:: resonance.linear_systems
   :members:
   :undoc-members:
   :show-inheritance:

resonance/nonlinear_systems.py
==============================

.. automodule:: resonance.nonlinear_systems
   :members:
   :undoc-members:
   :show-inheritance:

resonance/functions.py
======================

.. automodule:: resonance.functions
   :members:
   :undoc-members:
